@@ -1,13 +1,13 @@
-from dynabuffers.ast.AbstractAST import AbstractAST
+from dynabuffers.api.ISerializable import ISerializable
 
 
-class LongType(AbstractAST):
+class LongType(ISerializable):
 
     def size(self, value, registry):
         return 8
 
     def serialize(self, value, buffer, registry):
-        buffer.putFloat(value)
+        buffer.putLong(value)
 
     def deserialize(self, buffer, registry):
-        return buffer.getFloat()
+        return buffer.getLong()
